#ifndef RADIO8_H
#define RADIO8_H


#include <radio_mac.h>
#include <board.h> // for LEDs
#include <cc2511_map.h>
#include <dma.h>
#include <radio_registers.h>
//#include "debug.h"

/**
==Notes==
This uses the red LED to show packet transmission

We need to take control over the calibration, because I want to make
use of the rx_timout for packet scheduling.

*/

#define RADIO_COUNT 2
#define MAX_TIMEOUT 50
#define MAX_PACKET_LEN 5
#define RX_BUFFER_COUNT 4
#define TX_BUFFER_COUNT 3


/** Global Variables */
int32 CODE param_radio_channel = 128; // 0 - 255. Seperate by 2 channels to avoid crosstalk

uint8 XDATA rx_global_buffer[RX_BUFFER_COUNT][MAX_PACKET_LEN + 4]; // room to store CRC
int8 PDATA rx_buffer_index;
uint8 XDATA tx_global_buffer[TX_BUFFER_COUNT][MAX_PACKET_LEN];
int8 PDATA tx_buffer_index;

uint8 XDATA my_ID;
volatile uint8 XDATA * rx_packet;
volatile uint8 XDATA * tx_packet;
volatile uint8 PDATA rx_timeout = MAX_TIMEOUT;
volatile uint8 PDATA radio_tx_available = 0;

volatile uint8 DATA respond_state = 0;
#define MESSAGE_RCV 1
#define BAD_CRC 2
#define RADIO_ID_ERROR 3
#define RADIO_TIMEOUT 4


void radioInitAddendum() {
	rx_packet = *rx_global_buffer;
	tx_packet = *tx_global_buffer;
	CHANNR = param_radio_channel;
	PKTLEN = MAX_PACKET_LEN;
}


/* This function is declared in radio_mac.h, but needs to be defined here */
void radioMacEventHandler( uint8 event) {
	switch( event ) {
		
		case RADIO_MAC_EVENT_RX: //Packet recieved
			respond_state = MESSAGE_RCV;
			LED_YELLOW_TOGGLE();
			break;
		
		case RADIO_MAC_EVENT_RX_TIMEOUT:
			if(radio_tx_available){
				radioMacTx( tx_packet );
				LED_RED(1);
				--radio_tx_available;
			} else {
				radioMacRx( rx_packet, rx_timeout );
			}
			break;
			
		default:
			radioMacRx( rx_packet, rx_timeout );
			LED_RED(0);
			break;
	}
}

#endif